@@ -64,7 +64,7 @@
 
 #include "hildon-file-common-private.h"
 
-#define DEBUG
+/*#define DEBUG*/
 
 #define HILDON_RESPONSE_FOLDER_BUTTON 12345
 #define HILDON_RESPONSE_FOLDER_CREATED 54321
